High-level git operations.
Combines low-level git commands into operations suitable for the VFS sync workflow.
Structs
- GitOps
- High-level git operations.
Enums
- Startup
Sync Result - Startup sync result.
High-level git operations.
Combines low-level git commands into operations suitable for the VFS sync workflow.