pub struct GitSyncLifecycle { /* private fields */ }Expand description
Deep git workflow facade.
Implementations
Sourceimpl GitSyncLifecycle
impl GitSyncLifecycle
Sourcepub async fn open(
config: GitConfig,
local_dir: &Path,
) -> Result<(Self, GitInit)>
pub async fn open( config: GitConfig, local_dir: &Path, ) -> Result<(Self, GitInit)>
Open a repository and run startup synchronization.
Errors
Returns an error if the repository cannot be prepared or opened.
Sourcepub fn should_track(&self, path: &Path) -> bool
pub fn should_track(&self, path: &Path) -> bool
Return whether a path should be tracked.
Sourcepub async fn sync_local(&self, dirty_files: &[PathBuf]) -> Result<GitSync>
pub async fn sync_local(&self, dirty_files: &[PathBuf]) -> Result<GitSync>
Synchronize local dirty files to the Git remote.
Errors
Returns an error if git commit or push fails with a non-domain error.
Sourcepub async fn refresh_remote(&self) -> Result<GitRefresh>
pub async fn refresh_remote(&self) -> Result<GitRefresh>
Fetch and apply remote changes.
Errors
Returns an error if git fetch or pull fails with a non-domain error.
Sourcepub async fn refresh_remote_protected(
&self,
request: RemoteRefresh<'_>,
) -> Result<RemoteRefreshResult>
pub async fn refresh_remote_protected( &self, request: RemoteRefresh<'_>, ) -> Result<RemoteRefreshResult>
Detect remote changes, respect protected paths, and apply safe refreshes.
Errors
Returns an error if git inspection or pull fails with a non-domain error.